==> V1.2.9.tar.gz: joomla-sermon-distributor/README.md <==
# Sermon Distributor (1.2.9)

 ![Sermon Distributor image] (https://raw.githubusercontent.com/SermonDistributor/Joomla-3-Component/master/admin/assets/images/component-300.jpg "The Sermon Distributor")

Distributor is a highly advanced sermon distributor that runs on the [Joomla 3.x] (http://www.joomla.org) framework. You can link a shared folder from Dropbox to the component and use Dropbox as your file host, not to mention the advanced auto builder that gives you the ability to simply load sermons to your website by only adding them to Dropbox.

The best way to see all your options is to install this component on you Joomla website and test all features yourself. Here is a [direct download link] (https://github.com/SermonDistributor/Joomla-3-Component/archive/master.zip)

### Example Website, That Has Over 6000 Audio Files

[LoudVoice.org] (http://www.loudvoice.org)

### Some Video Demonstrations

+ [Setup overview] (https://youtu.be/yMPp1Cp3W_0?t=20m)
+ [Setup Dropbox] (https://youtu.be/btpKFDk0-dI)
+ [Component Build] (https://youtu.be/yMPp1Cp3W_0)

# Build Details

+ *Company*: [Vast Development Method] (https://www.vdm.io/)
+ *Author*: [Llewellyn van der Merwe] (mailto:llewellyn@vdm.io)
+ *Name*: [Sermon Distributor] (https://www.vdm.io/)
+ *First Build*: 22nd October, 2015
+ *Last Build*: 1st December, 2015
+ *Version*: 1.2.9
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

## Build Time :hourglass:

**126 Hours** or **16 Eight Hour Days** (actual time the author saved -
due to [Automated Component Builder] (https://www.vdm.io/joomla-component-builder))

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> never making one mistake or taking any coffee break.)

+ *Line count*: **45151**
+ *File count*: **347**
+ *Folder count*: **79**

**83 Hours** or **10 Eight Hour Days** (the actual time the author spent)

> (with the following break down:
> **debugging @32hours** = codingtime / 4;
> **planning @18hours** = codingtime / 7;
> **mapping @13hours** = codingtime / 10;
> **office @21hours** = codingtime / 6;)

**209 Hours** or **26 Eight Hour Days**
(a total of the realistic time frame for this project)

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> with the normal everyday realities at the office, that includes the component planning, mapping & debugging.)

Project duration: **5.2 weeks** or **1.1 months**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)

==> v1.3.0.tar.gz: joomla-sermon-distributor/README.md <==
# Sermon Distributor (1.3.0)

 ![Sermon Distributor image] (https://raw.githubusercontent.com/SermonDistributor/Joomla-3-Component/master/admin/assets/images/component-300.jpg "The Sermon Distributor")

Distributor is a highly advanced sermon distributor that runs on the [Joomla 3.x] (http://www.joomla.org) framework. You can link a shared folder from Dropbox to the component and use Dropbox as your file host, not to mention the advanced auto builder that gives you the ability to simply load sermons to your website by only adding them to Dropbox.

The best way to see all your options is to install this component on you Joomla website and test all features yourself. Here is a [direct download link] (https://github.com/SermonDistributor/Joomla-3-Component/archive/master.zip)

### Example Website, That Has Over 6000 Audio Files

[LoudVoice.org] (http://www.loudvoice.org)

### Some Video Demonstrations

+ [Setup overview] (https://youtu.be/yMPp1Cp3W_0?t=20m)
+ [Setup Dropbox] (https://youtu.be/btpKFDk0-dI)
+ [Component Build] (https://youtu.be/yMPp1Cp3W_0)

# Build Details

+ *Company*: [Vast Development Method] (https://www.vdm.io/)
+ *Author*: [Llewellyn van der Merwe] (mailto:llewellyn@vdm.io)
+ *Name*: [Sermon Distributor] (https://www.vdm.io/)
+ *First Build*: 22nd October, 2015
+ *Last Build*: 23rd December, 2015
+ *Version*: 1.3.0
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

## Build Time :hourglass:

**130 Hours** or **16 Eight Hour Days** (actual time the author saved -
due to [Automated Component Builder] (https://www.vdm.io/joomla-component-builder))

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> never making one mistake or taking any coffee break.)

+ *Line count*: **46561**
+ *File count*: **350**
+ *Folder count*: **79**

**86 Hours** or **11 Eight Hour Days** (the actual time the author spent)

> (with the following break down:
> **debugging @32hours** = codingtime / 4;
> **planning @19hours** = codingtime / 7;
> **mapping @13hours** = codingtime / 10;
> **office @22hours** = codingtime / 6;)

**216 Hours** or **27 Eight Hour Days**
(a total of the realistic time frame for this project)

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> with the normal everyday realities at the office, that includes the component planning, mapping & debugging.)

Project duration: **5.4 weeks** or **1.1 months**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)
